==> guayadeque_0.3.5~ds0.orig.tar.bz2: guayadeque-0.3.5~ds0.orig/src/dbus/mpris2.h <==
// -------------------------------------------------------------------------------- //
//	Copyright (C) 2008-2012 J.Rios
//	anonbeat@gmail.com
//
//    This Program is free software; you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation; either version 3, or (at your option)
//    any later version.
//
//    This Program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with this program; see the file LICENSE.  If not, write to
//    the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
//    http://www.gnu.org/copyleft/gpl.html
//
// -------------------------------------------------------------------------------- //
#ifndef MPRIS2_H
#define MPRIS2_H

#include "gudbus.h"
#include "PlayerPanel.h"

// -------------------------------------------------------------------------------- //
class guMPRIS2 : public guDBusClient
{
  protected :
    static guMPRIS2 *           m_MPRIS2;
    guPlayerPanel *             m_PlayerPanel;
    guDbLibrary *               m_Db;

  private :
    bool GetPlaylists( DBusMessage * msg, const dbus_int32_t start, const dbus_int32_t maxcount,
                         const char * order, const dbus_bool_t reverseorder );

  public :
    guMPRIS2( guDBusServer * server, guPlayerPanel * playerpanel, guDbLibrary * db );
    ~guMPRIS2();

    virtual DBusHandlerResult   HandleMessages( guDBusMessage * msg, guDBusMessage * reply = NULL );

    void                        OnPlayerTrackChange( void );
    void                        OnPlayerStatusChange( void );
    void                        OnPlayerCapsChange( void );
    void                        OnPlayerVolumeChange( void );
    void                        OnTrackListChange( void );

    bool                        Indicators_Sound_Available( void );
    int                         Indicators_Sound_BlacklistMediaPlayer( const dbus_bool_t blacklist = true );
    int                         Indicators_Sound_IsBlackListed( void );

    static void                 Set( guMPRIS2 * object ) { m_MPRIS2 = object; }
    static guMPRIS2 *           Get( void ) { return m_MPRIS2; }

};


#endif

// -------------------------------------------------------------------------------- //

==> guayadeque_0.3.7~ds0.orig.tar.bz2: guayadeque-0.3.7~ds0.orig/src/dbus/mpris2.h <==
// -------------------------------------------------------------------------------- //
//	Copyright (C) 2008-2013 J.Rios
//	anonbeat@gmail.com
//
//    This Program is free software; you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation; either version 3, or (at your option)
//    any later version.
//
//    This Program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with this program; see the file LICENSE.  If not, write to
//    the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
//    http://www.gnu.org/copyleft/gpl.html
//
// -------------------------------------------------------------------------------- //
#ifndef MPRIS2_H
#define MPRIS2_H

#include "gudbus.h"
#include "PlayerPanel.h"

// -------------------------------------------------------------------------------- //
class guMPRIS2 : public guDBusClient
{
  protected :
    static guMPRIS2 *           m_MPRIS2;
    guPlayerPanel *             m_PlayerPanel;
    guDbLibrary *               m_Db;

  private :
    bool GetPlaylists( DBusMessage * msg, const dbus_int32_t start, const dbus_int32_t maxcount,
                         const char * order, const dbus_bool_t reverseorder );

  public :
    guMPRIS2( guDBusServer * server, guPlayerPanel * playerpanel, guDbLibrary * db );
    ~guMPRIS2();

    virtual DBusHandlerResult   HandleMessages( guDBusMessage * msg, guDBusMessage * reply = NULL );

    void                        OnPlayerTrackChange( void );
    void                        OnPlayerStatusChange( void );
    void                        OnPlayerCapsChange( void );
    void                        OnPlayerVolumeChange( void );
    void                        OnTrackListChange( void );
    void                        OnFullscreenChanged( void );
    void                        OnPlayerSeeked( const unsigned int newpos );

    bool                        Indicators_Sound_Available( void );
    int                         Indicators_Sound_BlacklistMediaPlayer( const dbus_bool_t blacklist = true );
    int                         Indicators_Sound_IsBlackListed( void );

    static void                 Set( guMPRIS2 * object ) { m_MPRIS2 = object; }
    static guMPRIS2 *           Get( void ) { return m_MPRIS2; }

};


#endif

// -------------------------------------------------------------------------------- //
